@@ -1,19 +1,25 @@
-import os
-import pandas as pd
-import numpy as np
-from datetime import datetime
+# -*- coding: utf-8 -*-
+from mesures.dates import *
 from mesures.headers import ALMACENACAU_HEADER as columns
-from mesures.dates.date import REE_END_DATE
 from mesures.parsers.dummy_data import DummyKeys
+import os
+import numpy as np
+import pandas as pd
+
 
 class ALMACENACAU(object):
-    def __init__(self, data, distributor=None):
+    def __init__(self, data, distributor=None, compression='bz2'):
+        """
+        :param data: list of dicts or absolute file_path
+        :param distributor: str distributor REE code
+        :param compression: 'bz2', 'gz'... OR False otherwise
+        """
         data = DummyKeys(data).data
         self.file = self.reader(data)
         self.generation_date = datetime.now()
         self.prefix = 'ALMACENACAU'
         self.version = 0
-        self.default_compression = 'bz2'
+        self.default_compression = compression
         self.distributor = distributor
 
     def __repr__(self):
@@ -30,10 +36,17 @@ class ALMACENACAU(object):
 
     @property
     def filename(self):
-        return "{prefix}_{distributor}_{timestamp}.{version}".format(
-            prefix=self.prefix, distributor=self.distributor,
-            timestamp=self.generation_date.strftime('%Y%m%d'), version=self.version
-    )
+        if self.default_compression:
+            return "{prefix}_{distributor}_{timestamp}.{version}.{compression}".format(
+                prefix=self.prefix, distributor=self.distributor,
+                timestamp=self.generation_date.strftime('%Y%m%d'),
+                version=self.version, compression=self.default_compression
+            )
+        else:
+            return "{prefix}_{distributor}_{timestamp}.{version}".format(
+                prefix=self.prefix, distributor=self.distributor,
+                timestamp=self.generation_date.strftime('%Y%m%d'), version=self.version
+            )
 
     def reader(self, file_path):
         if isinstance(file_path, str):
@@ -49,7 +62,6 @@ class ALMACENACAU(object):
             lambda x: REE_END_DATE if not isinstance(x, pd.Timestamp) else x.strftime('%Y%m%d'))
         df['data_alta'] = df['data_alta'].apply(lambda x: x.strftime('%Y%m%d'))
         df['tecnologia_emmagatzematge'] = df['tecnologia_emmagatzematge'].astype(str)
-        df['tecnologia_emmagatzematge'] = df['tecnologia_emmagatzematge'].apply(lambda x: x.zfill(2))
         try:
             df['comentari'] = np.where(df['comentari'], df['comentari'], '')
         except KeyError:
@@ -60,7 +72,7 @@ class ALMACENACAU(object):
         """
         :return: file path of generated ALMACENACAU File
         """
-        file_path = os.path.join('/tmp', self.filename) + '.' + self.default_compression
+        file_path = os.path.join('/tmp', self.filename)
         self.file.to_csv(
             file_path, sep=';', header=False, columns=columns, index=False, line_terminator=';\n',
             compression=self.default_compression
