@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
-from datetime import datetime, timedelta
-from zipfile import ZipFile
+from mesures.dates import *
 from mesures.headers import F5D_HEADER as columns
 from mesures.parsers.dummy_data import DummyCurve
+from zipfile import ZipFile
 import os
 import pandas as pd
 
+
 DTYPES = {'cups': 'category',
           'season': 'category',
           'ai': 'int64',
@@ -21,13 +22,19 @@ DTYPES = {'cups': 'category',
 
 
 class F5(object):
-    def __init__(self, data, distributor=None, comer=None):
+    def __init__(self, data, distributor=None, comer=None, compression='bz2'):
+        """
+        :param data: list of dicts or absolute file_path
+        :param distributor: str distributor REE code
+        :param comer: str comer REE code
+        :param compression: 'bz2', 'gz'... OR False otherwise
+        """
         if isinstance(data, list):
             data = DummyCurve(data).curve_data
         self.file = self.reader(data)
         self.generation_date = datetime.now()
         self.prefix = 'F5'
-        self.default_compression = 'bz2'
+        self.default_compression = compression
         self.version = 0
         self.distributor = distributor
         self.comer = comer
@@ -52,9 +59,24 @@ class F5(object):
 
     @property
     def filename(self):
-        return "{prefix}_{distributor}_{comer}_{measures_date}_{timestamp}.{version}".format(
-            prefix=self.prefix, distributor=self.distributor, comer=self.comer, measures_date=self.measures_date.strftime('%Y%m%d'),
-            timestamp=self.generation_date.strftime('%Y%m%d'), version=self.version
+        if self.default_compression:
+            return "{prefix}_{distributor}_{comer}_{measures_date}_{timestamp}.{version}.{compression}".format(
+                prefix=self.prefix, distributor=self.distributor, comer=self.comer,
+                measures_date=self.measures_date.strftime('%Y%m%d'), timestamp=self.generation_date.strftime('%Y%m%d'),
+                version=self.version, compression=self.default_compression
+            )
+        else:
+            return "{prefix}_{distributor}_{comer}_{measures_date}_{timestamp}.{version}".format(
+                prefix=self.prefix, distributor=self.distributor, comer=self.comer,
+                measures_date=self.measures_date.strftime('%Y%m%d'), timestamp=self.generation_date.strftime('%Y%m%d'),
+                version=self.version
+            )
+
+    @property
+    def zip_filename(self):
+        return "{prefix}_{distributor}_{comer}_{measures_date}_{timestamp}.zip".format(
+            prefix=self.prefix, distributor=self.distributor, comer=self.comer,
+            measures_date=self.measures_date.strftime('%Y%m%d'), timestamp=self.generation_date.strftime('%Y%m%d')
         )
 
     @property
@@ -128,16 +150,17 @@ class F5(object):
         daymax = self.file['timestamp'].max()
         self.measures_date = daymin
         #todo: get a zip filename without measures_date
-        zipped_file = ZipFile(os.path.join('/tmp', self.filename + '.zip'), 'w')
+        zipped_file = ZipFile(os.path.join('/tmp', self.zip_filename), 'w')
         while daymin <= daymax:
             di = daymin
             df = daymin + timedelta(days=1)
             self.measures_date = di
             dataf = self.file[(self.file['timestamp'] >= di) & (self.file['timestamp'] < df)]
             dataf['timestamp'] = dataf['timestamp'].apply(lambda x: x.strftime('%Y/%m/%d %H:%M'))
-            filepath = os.path.join('/tmp', self.filename) + '.' + self.default_compression
+            filepath = os.path.join('/tmp', self.filename)
             dataf.to_csv(
-                filepath, sep=';', header=False, columns=columns, index=False, line_terminator=';\n'
+                filepath, sep=';', header=False, columns=columns, index=False, line_terminator=';\n',
+                compression=self.default_compression
             )
             daymin = df
             zipped_file.write(filepath, arcname=os.path.basename(filepath))
