@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+from six import string_types
 import numpy as np
 import pandas as pd
 
@@ -19,11 +21,13 @@ class DummyCurve(object):
                 data['timestamp'] = data.pop('datetime')
             if 'local_datetime' in data:
                 data['timestamp'] = data.pop('local_datetime')
-            data['timestamp'] = pd.Timestamp(data['timestamp'])
+            if 'timestamp' in data:
+                data['timestamp'] = pd.Timestamp(data['timestamp'])
             if 'estacio' in data:
                 data['season'] = data.pop('estacio')
             if 'season' not in data:
-                data['season'] = int(data['timestamp'].dst().seconds > 0)
+                if 'timestamp' in data:
+                    data['season'] = int(data['timestamp'].dst().seconds > 0)
             if 'as' in data:
                 # Active saliente and entrante
                 data['ae'] = data.pop('as')
@@ -32,7 +36,7 @@ class DummyCurve(object):
                 # Active input and output
                 data['ai'] = data.pop('ai')
                 data['ae'] = data.pop('ao')
-            if 'season' in data and (isinstance(data['season'], str) or isinstance(data['season'], unicode)):
+            if 'season' in data and isinstance(data['season'], string_types):
                 try:
                     data['season'] = int(data['season'])
                 except ValueError:
